# NAME
    isin_grid

# DESCRIPTION
    Author: Brendan DeTracey
    Code adapted from seadas v7.5:
    build/src/libbin++/L3BinShape.cpp
    build/src/libbin++/bin_io.cpp
    /*
     The following functions are based on the pseudocode found in Appendix A of:
    
     Campbell, J.W., J.M. Blaisdell, and M. Darzi, 1995:
     Level-3 SeaWiFS Data Products: Spatial and Temporal Binning Algorithms.
     NASA Tech. Memo. 104566, Vol. 32,
     S.B. Hooker, E.R. Firestone, and J.G. Acker, Eds.,
     NASA Goddard Space Flight Center, Greenbelt, Maryland
     */
    
     Adapted and extended by Sean Bailey <sean.w.bailey@nasa.gov>

# CLASSES
        L3BinGrid
    
##    class L3BinGrid(builtins.object)
 L3BinGrid(*argv, totalrows=4320, resolve=None)
 
 A Level 3 bin (L3b) class
 
 This class provides methods for forward and inverse calculations of the 
 integerized sinusoidal grid bin numbers and latitudes and longitudes
 
 The class can be initialized with totalrows or the string "resolve" which
 will set total rows.  Default is to initialize to a 4.62km grid (resolve = "4")
 
 Methods defined here:
 
 __init__(self, *argv, totalrows=4320, resolve=None)
     Initialize self.  See help(type(self)) for accurate signature.
 
 bin2bounds(self, _bin)
     Returns the bounding north, south, east and west values  corresponding to a given bin number.
     
         Parameters:
                 bin (int): L3 bin number
     
         Returns:
                 north (float): northernmost latitude
                 south (float): southernmost latitude
                 east (float): easternmost longitude
                 west (float): westernmost longitude
 
###  bin2lonlat(self, _bin)
     Returns the longitude and latitude  corresponding to a given bin number.
     
         Parameters:
                 bin (int): L3 bin number
     
         Returns:
                 lon (float): longitude 
                 lat (float): latitude
 
###  bin2row(self, _bin)
     Returns the row corresponding to a bin number.
     
         Parameters:
                 _bin (int): L3 bin  
     
         Returns:
                 row (int): L3 row number
 
###  bin2rowcol(self, _bin)
     Returns the row and column corresponding to a bin number.
     
         Parameters:
                 _bin (int): L3 bin  
     
         Returns:
                 row (int): L3 row number
                 col (int): L3 column number
 
###  lat2row(self, lat)
     Returns the bin row number corresponding to a given latitude.
     
         Parameters:
                 lat (float): latitude
     
         Returns:
                 row (int): L3 row number
 
###  lonlat2bin(self, lon, lat)
     Returns the bin number corresponding to a given longitude and latitude.
     
         Parameters:
                 lon (float): longitude 
                 lat (float): latitude
     
         Returns:
                 bin (int): L3 bin number
 
###  lonlat2rowcol(self, lon, lat)
     Returns the row and column corresponding to a given longitude and latitude.
     
         Parameters:
                 lon (float): longitude 
                 lat (float): latitude
     
         Returns:
                 row (int): L3 row number
                 col (int): L3 column number
 
###  region2bins(self, north, south, west, east)
     Returns the bin numbers for a bounding north, south, east and west box  
     
         Parameters:
             north (float): northernmost latitude
             south (float): southernmost latitude
             east (float): easternmost longitude
             west (float): westernmost longitude
     
         Returns:
             numpy array of bin numbers
 
###  rowcol2bin(self, row, col)
     Returns the bin number corresponding to a given row and column.
     
         Parameters:
                 row (int): L3bin row 
                 col (int): L3bin column
     
         Returns:
                 bin (int): L3 bin number
 
###  rowcol2bounds(self, row, col)
     Returns the bounding north, south, east and west values  
     corresponding to a row and column.
     
         Parameters:
                 row (int): L3bin row 
                 col (int): L3bin column
     
         Returns:
                 north (float): northernmost latitude
                 south (float): southernmost latitude
                 east (float): easternmost longitude
                 west (float): westernmost longitude
 
###  rowcol2lonlat(self, row, col)
     Returns the latitude and longitude number corresponding to a given row and column.
     
         Parameters:
                 row (int): L3bin row 
                 col (int): L3bin column
     
         Returns:
                 lon (float): longitude 
                 lat (float): latitude
 
###  rowlon2bin(self, row, lon)
     Returns the bin number corresponding to a given row and longitude.
     
         Parameters:
                 row (int): L3bin row 
                 col (int): L3bin column
     
         Returns:
                 bin (int): L3 bin number
 

## VERSION
    1.1.0